@@ -10,16 +10,30 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 
-config etc/magic.new
+#config etc/file/magic.mgc.new
+#config etc/file/magic.mime.mgc.new
+config etc/file/magic.mime.new
+config etc/file/magic.new
 
+# Don't let an upgrade nuke someone's old /etc/magic files:
+if [ -f etc/magic -a ! -L etc/magic ]; then
+  mv etc/magic etc/magic.old
+fi
+if [ -f etc/magic.mime -a ! -L etc/magic.mime ]; then
+  mv etc/magic.mime etc/magic.mime.old
+fi
+
+( cd etc ; rm -rf magic )
+( cd etc ; ln -sf file/magic magic )
+( cd etc ; rm -rf magic.mime )
+( cd etc ; ln -sf file/magic.mime magic.mime )
+( cd usr/bin ; rm -rf uncompress )
 ( cd usr/bin ; rm -rf uncompress )
 ( cd usr/bin ; ln -sf compress uncompress )
 ( cd usr/bin ; rm -rf rpm2tgz )
 ( cd usr/bin ; ln -sf rpm2targz rpm2tgz )
 ( cd usr/lib ; rm -rf makewhatis )
 ( cd usr/lib ; ln -sf /usr/sbin/makewhatis makewhatis )
-( cd sbin ; rm -rf fsck.reiserfs )
-( cd sbin ; ln -sf /bin/true fsck.reiserfs )
 ( cd sbin ; rm -rf fsck.hpfs )
 ( cd sbin ; ln -sf /bin/true fsck.hpfs )
 ( cd sbin ; rm -rf fsck.msdos )
@@ -32,3 +46,7 @@ config etc/magic.new
 ( cd bin ; ln -sf ed red )
 ( cd bin ; rm -rf compress )
 ( cd bin ; ln -sf /usr/bin/compress compress )
+( cd usr/bin ; rm -rf which )
+( cd usr/bin ; ln -sf ../../bin/which which )
+( cd etc ; rm -rf magic )
+( cd etc ; ln -sf file/magic magic )
